OpenSeesPyMac

OpenSeesPy for the Mac OS. Supports OSX 10.13-11 (High Sierra to Big Sur)

Requires Python 3.8 or higher <https://www.python.org/downloads/> 

Mac version maintained by:

Dr. Stevan Gavrilovic <gavrilovic@berkeley.edu>,
University of California, Berkeley

OpenSeesPy Developer:

Minjie Zhu <zhum@oregonstate.edu>

Faculty Research Assistant,
Civil and Construction Engineering,
Oregon State University

OpenSeesPy Documentation <https://openseespydoc.readthedocs.io/en/latest/index.html>

